@@ -16,8 +16,7 @@ var searchData=
   ['calendarfieldindex_2eidl',['CalendarFieldIndex.idl',['../CalendarFieldIndex_8idl.html',1,'']]],
   ['calendaritem_2eidl',['CalendarItem.idl',['../CalendarItem_8idl.html',1,'']]],
   ['calendaritem2_2eidl',['CalendarItem2.idl',['../CalendarItem2_8idl.html',1,'']]],
-  ['callablestatement_2eidl',['CallableStatement.idl',['../CallableStatement_8idl.html',1,'']]],
-  ['callablestatement_2eidl',['CallableStatement.idl',['../_2CallableStatement_8idl.html',1,'']]],
+  ['callablestatement_2eidl',['CallableStatement.idl',['../CallableStatement_8idl.html',1,'(Global Namespace)'],['../_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
   ['camerageometry_2eidl',['CameraGeometry.idl',['../CameraGeometry_8idl.html',1,'']]],
   ['candlestickcharttype_2eidl',['CandleStickChartType.idl',['../CandleStickChartType_8idl.html',1,'']]],
   ['cannotactivatefactoryexception_2eidl',['CannotActivateFactoryException.idl',['../CannotActivateFactoryException_8idl.html',1,'']]],
@@ -36,8 +35,7 @@ var searchData=
   ['cartesiancoordinatesystem2d_2eidl',['CartesianCoordinateSystem2d.idl',['../CartesianCoordinateSystem2d_8idl.html',1,'']]],
   ['cartesiancoordinatesystem3d_2eidl',['CartesianCoordinateSystem3d.idl',['../CartesianCoordinateSystem3d_8idl.html',1,'']]],
   ['casemap_2eidl',['CaseMap.idl',['../CaseMap_8idl.html',1,'']]],
-  ['cell_2eidl',['Cell.idl',['../table_2Cell_8idl.html',1,'']]],
-  ['cell_2eidl',['Cell.idl',['../text_2Cell_8idl.html',1,'']]],
+  ['cell_2eidl',['Cell.idl',['../table_2Cell_8idl.html',1,'(Global Namespace)'],['../text_2Cell_8idl.html',1,'(Global Namespace)']]],
   ['celladdress_2eidl',['CellAddress.idl',['../CellAddress_8idl.html',1,'']]],
   ['cellannotation_2eidl',['CellAnnotation.idl',['../CellAnnotation_8idl.html',1,'']]],
   ['cellannotations_2eidl',['CellAnnotations.idl',['../CellAnnotations_8idl.html',1,'']]],
@@ -57,11 +55,9 @@ var searchData=
   ['cellinsertmode_2eidl',['CellInsertMode.idl',['../CellInsertMode_8idl.html',1,'']]],
   ['celljustifymethod_2eidl',['CellJustifyMethod.idl',['../CellJustifyMethod_8idl.html',1,'']]],
   ['cellorientation_2eidl',['CellOrientation.idl',['../CellOrientation_8idl.html',1,'']]],
-  ['cellproperties_2eidl',['CellProperties.idl',['../table_2CellProperties_8idl.html',1,'']]],
-  ['cellproperties_2eidl',['CellProperties.idl',['../text_2CellProperties_8idl.html',1,'']]],
+  ['cellproperties_2eidl',['CellProperties.idl',['../table_2CellProperties_8idl.html',1,'(Global Namespace)'],['../text_2CellProperties_8idl.html',1,'(Global Namespace)']]],
   ['cellprotection_2eidl',['CellProtection.idl',['../CellProtection_8idl.html',1,'']]],
-  ['cellrange_2eidl',['CellRange.idl',['../table_2CellRange_8idl.html',1,'']]],
-  ['cellrange_2eidl',['CellRange.idl',['../text_2CellRange_8idl.html',1,'']]],
+  ['cellrange_2eidl',['CellRange.idl',['../table_2CellRange_8idl.html',1,'(Global Namespace)'],['../text_2CellRange_8idl.html',1,'(Global Namespace)']]],
   ['cellrangeaddress_2eidl',['CellRangeAddress.idl',['../CellRangeAddress_8idl.html',1,'']]],
   ['cellrangelistsource_2eidl',['CellRangeListSource.idl',['../CellRangeListSource_8idl.html',1,'']]],
   ['cells_2eidl',['Cells.idl',['../Cells_8idl.html',1,'']]],
@@ -122,8 +118,7 @@ var searchData=
   ['chartdatarowproperties_2eidl',['ChartDataRowProperties.idl',['../ChartDataRowProperties_8idl.html',1,'']]],
   ['chartdatarowsource_2eidl',['ChartDataRowSource.idl',['../ChartDataRowSource_8idl.html',1,'']]],
   ['chartdatavalue_2eidl',['ChartDataValue.idl',['../ChartDataValue_8idl.html',1,'']]],
-  ['chartdocument_2eidl',['ChartDocument.idl',['../ChartDocument_8idl.html',1,'']]],
-  ['chartdocument_2eidl',['ChartDocument.idl',['../_2ChartDocument_8idl.html',1,'']]],
+  ['chartdocument_2eidl',['ChartDocument.idl',['../ChartDocument_8idl.html',1,'(Global Namespace)'],['../_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
   ['chartdocumentwrapper_2eidl',['ChartDocumentWrapper.idl',['../ChartDocumentWrapper_8idl.html',1,'']]],
   ['charterrorcategory_2eidl',['ChartErrorCategory.idl',['../ChartErrorCategory_8idl.html',1,'']]],
   ['charterrorindicatortype_2eidl',['ChartErrorIndicatorType.idl',['../ChartErrorIndicatorType_8idl.html',1,'']]],
@@ -147,8 +142,7 @@ var searchData=
   ['charttypemanager_2eidl',['ChartTypeManager.idl',['../ChartTypeManager_8idl.html',1,'']]],
   ['charttypetemplate_2eidl',['ChartTypeTemplate.idl',['../ChartTypeTemplate_8idl.html',1,'']]],
   ['chartype_2eidl',['CharType.idl',['../CharType_8idl.html',1,'']]],
-  ['checkbox_2eidl',['CheckBox.idl',['../component_2CheckBox_8idl.html',1,'']]],
-  ['checkbox_2eidl',['CheckBox.idl',['../control_2CheckBox_8idl.html',1,'']]],
+  ['checkbox_2eidl',['CheckBox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
   ['checkinargument_2eidl',['CheckinArgument.idl',['../CheckinArgument_8idl.html',1,'']]],
   ['checkoption_2eidl',['CheckOption.idl',['../CheckOption_8idl.html',1,'']]],
   ['cipherid_2eidl',['CipherID.idl',['../CipherID_8idl.html',1,'']]],
@@ -166,8 +160,7 @@ var searchData=
   ['cmisversion_2eidl',['CmisVersion.idl',['../CmisVersion_8idl.html',1,'']]],
   ['collator_2eidl',['Collator.idl',['../Collator_8idl.html',1,'']]],
   ['collatoroptions_2eidl',['CollatorOptions.idl',['../CollatorOptions_8idl.html',1,'']]],
-  ['color_2eidl',['Color.idl',['../rendering_2Color_8idl.html',1,'']]],
-  ['color_2eidl',['Color.idl',['../util_2Color_8idl.html',1,'']]],
+  ['color_2eidl',['Color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
   ['colorcomponent_2eidl',['ColorComponent.idl',['../ColorComponent_8idl.html',1,'']]],
   ['colorcomponenttag_2eidl',['ColorComponentTag.idl',['../ColorComponentTag_8idl.html',1,'']]],
   ['colormode_2eidl',['ColorMode.idl',['../ColorMode_8idl.html',1,'']]],
@@ -177,8 +170,7 @@ var searchData=
   ['colorscaleentrytype_2eidl',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
   ['colortable_2eidl',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl',['Column.idl',['../Column_8idl.html',1,'']]],
-  ['column_2eidl',['Column.idl',['../x_2Column_8idl.html',1,'']]],
+  ['column_2eidl',['Column.idl',['../Column_8idl.html',1,'(Global Namespace)'],['../x_2Column_8idl.html',1,'(Global Namespace)']]],
   ['columndescriptor_2eidl',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
   ['columndescriptorcontrol_2eidl',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
   ['columndescriptorcontrolmodel_2eidl',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
@@ -188,14 +180,10 @@ var searchData=
   ['columntype_2eidl',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
   ['columnvalue_2eidl',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
   ['combinedcharacters_2eidl',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
-  ['combobox_2eidl',['ComboBox.idl',['../control_2ComboBox_8idl.html',1,'']]],
-  ['combobox_2eidl',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'']]],
-  ['command_2eidl',['Command.idl',['../awt_2Command_8idl.html',1,'']]],
-  ['command_2eidl',['Command.idl',['../animations_2Command_8idl.html',1,'']]],
-  ['command_2eidl',['Command.idl',['../ucb_2Command_8idl.html',1,'']]],
+  ['combobox_2eidl',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl',['Command.idl',['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
   ['commandabortedexception_2eidl',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
-  ['commandbutton_2eidl',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'']]],
-  ['commandbutton_2eidl',['CommandButton.idl',['../control_2CommandButton_8idl.html',1,'']]],
+  ['commandbutton_2eidl',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'(Global Namespace)'],['../control_2CommandButton_8idl.html',1,'(Global Namespace)']]],
   ['commanddefinition_2eidl',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
   ['commandenvironment_2eidl',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
   ['commandfailedexception_2eidl',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
@@ -228,8 +216,7 @@ var searchData=
   ['configurationregistry_2eidl',['ConfigurationRegistry.idl',['../ConfigurationRegistry_8idl.html',1,'']]],
   ['configurationupdateaccess_2eidl',['ConfigurationUpdateAccess.idl',['../ConfigurationUpdateAccess_8idl.html',1,'']]],
   ['connectexception_2eidl',['ConnectException.idl',['../ConnectException_8idl.html',1,'']]],
-  ['connection_2eidl',['Connection.idl',['../_2Connection_8idl.html',1,'']]],
-  ['connection_2eidl',['Connection.idl',['../Connection_8idl.html',1,'']]],
+  ['connection_2eidl',['Connection.idl',['../Connection_8idl.html',1,'(Global Namespace)'],['../_2Connection_8idl.html',1,'(Global Namespace)']]],
   ['connectionlostexception_2eidl',['ConnectionLostException.idl',['../ConnectionLostException_8idl.html',1,'']]],
   ['connectionmode_2eidl',['ConnectionMode.idl',['../ConnectionMode_8idl.html',1,'']]],
   ['connectionpool_2eidl',['ConnectionPool.idl',['../ConnectionPool_8idl.html',1,'']]],
@@ -304,11 +291,9 @@ var searchData=
   ['cryptographyexception_2eidl',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
   ['csvlogformatter_2eidl',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
   ['ctlscripttype_2eidl',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
-  ['currency_2eidl',['Currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'']]],
-  ['currency_2eidl',['Currency.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'']]],
+  ['currency_2eidl',['Currency.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)']]],
   ['currency2_2eidl',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
-  ['currencyfield_2eidl',['CurrencyField.idl',['../component_2CurrencyField_8idl.html',1,'']]],
-  ['currencyfield_2eidl',['CurrencyField.idl',['../control_2CurrencyField_8idl.html',1,'']]],
+  ['currencyfield_2eidl',['CurrencyField.idl',['../component_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../control_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
   ['curvestyle_2eidl',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
   ['custom_2eidl',['Custom.idl',['../Custom_8idl.html',1,'']]],
   ['custompresentation_2eidl',['CustomPresentation.idl',['../CustomPresentation_8idl.html',1,'']]],
